.eom-window statusbar progressbar.horizontal,
.eom-window statusbar progressbar.horizontal trough,
EomStatusbar GtkProgressBar {
    -GtkProgressBar-min-horizontal-bar-height: 14;
    min-height: 14px;
}
